@@ -4,10 +4,12 @@
 #
 # Copyright (C) 2020 - Equinor ASA.
 
-import webviz_subsurface_components
 import dash
 import dash_html_components as html
 
+import webviz_subsurface_components
+
+
 app = dash.Dash(__name__)
 
 output = [
@@ -63,12 +65,11 @@ parameters = [
         "interactions": [0.0, 114457.6, 180225.4, 201267.2],
     },
 ]
-parameter = "FOPT"
 
 app.layout = html.Div(
     children=[
         webviz_subsurface_components.Morris(
-            id="morris_chart", output=output, parameters=parameters, parameter=parameter
+            id="morris_chart", output=output, parameters=parameters, parameter="FOPT"
         ),
     ]
 )
