@@ -1,5 +1,6 @@
 import { Icon } from "@equinor/eds-core-react";
 import {
+    map,
     well,
     brush,
     fault,
@@ -11,6 +12,7 @@ import {
 
 // (this needs only be done once)
 Icon.add({
+    map,
     well,
     brush,
     fault,
@@ -82,7 +84,7 @@ export const LayerIcons = {
     ColormapLayer: "surface_layer",
     Hillshading2DLayer: "hill_shading",
     WellsLayer: "well",
-    Map3DLayer: "fault",
+    Map3DLayer: "map",
     PieChartLayer: "pie_chart",
     GridLayer: "grid_layer",
     FaultPolygonsLayer: "fault",
