@@ -278,7 +278,7 @@ const meshMapLayer = {
     propertyValueRange: [2782, 3513],
     rotDeg: 0,
     contours: [0, 50.0],
-    isContoursDepth: true,
+    isContoursDepth: false,
     colorMapName: "Physics",
 };
 export const KhMapMesh = MinimalTemplate.bind({});
@@ -289,6 +289,9 @@ KhMapMesh.args = {
             ...meshMapLayer,
         },
     ],
+    toolbar: {
+        visible: false,
+    },
     bounds: [432150, 6475800, 439400, 6481500],
     views: {
         layout: [1, 1],
@@ -302,6 +305,90 @@ KhMapMesh.args = {
     },
 };
 
+//Material property may take these values:
+//          true  = default material. See deck.gl documentation for what that is. This is default property value.
+//          false = no material.
+//          Full spec:
+//                {
+//                    ambient: 0.35,
+//                    diffuse: 0.6,
+//                    shininess: 32,
+//                    specularColor: [255, 255, 255],
+//                }
+const material = {
+    ambient: 0.35,
+    diffuse: 0.6,
+    shininess: 32,
+    specularColor: [255, 255, 255],
+};
+export const MapMaterial = MinimalTemplate.bind({});
+MapMaterial.args = {
+    id: "material",
+    layers: [{ ...meshMapLayer, material }],
+    bounds: [432150, 6475800, 439400, 6481500],
+    views: {
+        layout: [1, 1],
+        viewports: [
+            {
+                id: "view_1",
+                show3D: false,
+                layerIds: [],
+            },
+        ],
+    },
+};
+MapMaterial.parameters = {
+    docs: {
+        description: {
+            story: "An example showing example usage of Map3D material property.",
+        },
+        inlineStories: false,
+        iframeHeight: 500,
+    },
+};
+
+// Exapmple of using "colorMapClampColor" property.
+// Clamps colormap to this color at ends.
+// Given as array of three values (r,g,b) e.g: [255, 0, 0]
+// If not set (undefined) or set to true, it will clamp to color map min and max values.
+// If set to false the clamp color will be completely transparent.
+const propertyValueRange = [2782, 3513];
+const colorMapRange = [3000, 3513];
+const colorMapClampColor = [0, 255, 0]; // a color e.g. [0, 255, 0],  false, true or undefined.
+
+export const MapClampColor = MinimalTemplate.bind({});
+MapClampColor.args = {
+    id: "clampcolor",
+    layers: [
+        {
+            ...meshMapLayer,
+            propertyValueRange,
+            colorMapRange,
+            colorMapClampColor,
+        },
+    ],
+    bounds: [432150, 6475800, 439400, 6481500],
+    views: {
+        layout: [1, 1],
+        viewports: [
+            {
+                id: "view_1",
+                show3D: false,
+                layerIds: [],
+            },
+        ],
+    },
+};
+MapClampColor.parameters = {
+    docs: {
+        description: {
+            story: 'An example usage of map property `"colorMapClampColor"',
+        },
+        inlineStories: false,
+        iframeHeight: 500,
+    },
+};
+
 const axes = {
     "@@type": "AxesLayer",
     id: "axes-layer",
@@ -335,6 +422,9 @@ GridLayer.args = {
             visible: true,
         },
     ],
+    toolbar: {
+        visible: false,
+    },
     views: {
         layout: [1, 1],
         viewports: [
@@ -455,3 +545,50 @@ ExperimentalMapLayerFloat32Property.parameters = {
         iframeHeight: 500,
     },
 };
+
+// ---------Selectable GeoJson Layer example--------------- //
+export const SelectableFeatureExample = (args) => {
+    const [editedData, setEditedData] = React.useState(args.editedData);
+    React.useEffect(() => {
+        setEditedData(args.editedData);
+    }, [args.editedData]);
+    return (
+        <div>
+            <DeckGLMap
+                {...args}
+                editedData={editedData}
+                setProps={(updatedProps) => {
+                    setEditedData(updatedProps.editedData);
+                }}
+            />
+            <pre>{JSON.stringify(editedData, null, 2)}</pre>
+        </div>
+    );
+};
+
+SelectableFeatureExample.parameters = {
+    docs: {
+        description: {
+            story: "An example showing selectable feature example from the map.",
+        },
+    },
+};
+
+const polylineUsingSelectableGeoJsonLayer = {
+    ...customLayerWithPolylineData,
+    "@@type": "SelectableGeoJsonLayer",
+};
+
+const polygonUsingSelectableGeoJsonLayer = {
+    ...customLayerWithPolygonData,
+    "@@type": "SelectableGeoJsonLayer",
+};
+
+SelectableFeatureExample.args = {
+    id: "DeckGL-Map",
+    bounds: [432205, 6475078, 437720, 6481113],
+    layers: [
+        polylineUsingSelectableGeoJsonLayer,
+        polygonUsingSelectableGeoJsonLayer,
+    ],
+};
